'use strict';

const preset = {
  modes: [],
  themes: [],
  codemirror: false,
  includeTags: false,
  includeComments: false,
  includeBrackets: false,
  includeWhitespace: false,
};

module.exports = {
  name: '@abcum/ember-editables',
  included(app) {

    this._super.included(app);

    let config = this.project.config(process.env.EMBER_ENV).editables || {};

    Object.keys(preset).forEach(function(key) {
      if (typeof config[key] === 'undefined') {
        config[key] = preset[key];
      }
    });

    if (config.codemirror) {

      app.import('node_modules/codemirror/lib/codemirror.js');
      app.import('node_modules/codemirror/lib/codemirror.css');
      app.import('node_modules/codemirror/addon/mode/simple.js');
      app.import('node_modules/codemirror/addon/mode/multiplex.js');

      if (config.includeTags) {
        app.import('node_modules/codemirror/addon/edit/closetag.js');
        app.import('node_modules/codemirror/addon/edit/matchtags.js');
      }

      if (config.includeBrackets) {
        app.import('node_modules/codemirror/addon/edit/closebrackets.js');
        app.import('node_modules/codemirror/addon/edit/matchbrackets.js');
      }

      if (config.includeComments) {
        app.import('node_modules/codemirror/addon/comment/comment.js');
      }

      if (config.includeWhitespace) {
        app.import('node_modules/codemirror/addon/edit/trailingspace.js');
      }

      config.modes.forEach(function(m) {
        app.import('node_modules/codemirror/mode/'+m+'/'+m+'.js');
      });

      config.themes.forEach(function(t) {
        app.import('node_modules/codemirror/theme/'+t+'.css');
      });

      app.import('vendor/codemirror.css');
      app.import('vendor/codemirror.js', {
        exports: {
          CodeMirror: ['default']
        }
      });

    }

  },

};
